@@ -4,7 +4,7 @@ use Moose;
 use MooseX::Method::Signatures;
 use YAML qw(LoadFile DumpFile);
 use App::Toodledo::Util qw(debug);
-
+with 'MooseX::Log::Log4perl';
 has filename => ( is => 'rw', isa => 'Str', );
 
 has password_ref => ( is => 'rw', isa => 'HashRef[Str]',
@@ -20,7 +20,7 @@ method new_from_file ( $class: Str $file! ) {
     my $ref = LoadFile( $file );
     my ($password_ref, $app_token_ref, $default_user_id)
       = @{$ref}{qw(passwords app_tokens default_user_id)};
-    debug "Loaded info cache from $file\n";
+    $class->log->debug("Loaded info cache from $file");
     return $class->new( filename        => $file,
 			password_ref    => $password_ref,
 			app_token_ref   => $app_token_ref,
@@ -42,6 +42,7 @@ method save_to_file ( Str $filename! ) {
 
 
 method save () {
+  $self->log->debug("test");
   $self->save_to_file( $self->filename );
 }
 
